#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cborg-json
version:              0.2.6.0
visibility:           public
id:                   cborg-json-0.2.6.0-J5IF2lHdNTYBNqunbqlxcE
key:                  cborg-json-0.2.6.0-J5IF2lHdNTYBNqunbqlxcE
license:              BSD-3-Clause
copyright:
    2015-2017 Duncan Coutts,
    2015-2017 Well-Typed LLP,
    2015 IRIS Connect Ltd

maintainer:           ben@smart-cactus.org
author:               Duncan Coutts
homepage:             https://github.com/well-typed/cborg
synopsis:             A library for encoding JSON as CBOR
description:
    This package implements the bijection between JSON and
    CBOR defined in the CBOR specification, RFC 7049.

category:             Codec
abi:                  fd659803c6c16f94c6a8ff26568bb013
exposed:              True
exposed-modules:      Codec.CBOR.JSON
import-dirs:          /usr/lib/ghc-9.6.6/site-local/cborg-json-0.2.6.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/cborg-json-0.2.6.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/cborg-json-0.2.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cborg-json
hs-libraries:         HScborg-json-0.2.6.0-J5IF2lHdNTYBNqunbqlxcE
depends:
    aeson-2.2.2.0-3pjCpj5XtaHAHmzSwnt06z
    aeson-pretty-0.8.11-14Ddz3zmjAB9aNGz5rrQGd base-4.18.2.1
    base64-bytestring-1.2.1.0-LZzfJtlIG52AkUlWG0qoMe
    cborg-0.2.10.0-9vFmyBDaFTY2ZcQdRfOzir
    scientific-0.3.8.1-H3VUewCJEy81jq03Pb0rn3 text-2.0.2
    unordered-containers-0.2.21-5Z67IC6H036CG8YRUzTmvt
    vector-0.13.2.0-9mJIQr0XJi1KVzSJMcMTkU

haddock-interfaces:   /usr/share/doc/haskell-cborg-json/html/cborg-json.haddock
haddock-html:         /usr/share/doc/haskell-cborg-json/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

